<template>
    <div class="search-panel">
        <el-form ref="form" :model="form" label-width="90px" class="search-form">
            <el-form ref="form" :model="form" label-width="90px" class="search-form">
                <el-form-item label="企业名称：" size="mini" class="search-panel-item">
                    <el-select style="width: 100%" v-model="form.pipelineType" @change="handlePipelineType"
                               :popper-class="'select-down'">
                        <el-option
                                v-for="item in items"
                                :key="item.code"
                                :label="item.name"
                                :value="item.name">
                        </el-option>
                    </el-select>
                </el-form-item>
                <el-form-item label="事件状态：" size="mini">
                    <el-select style="width: 100%" v-model="form.dataType" value-key="code"
                               :popper-class="'select-down'" @change="handleDataType">
                        <el-option
                                v-for="item in subItems"
                                :key="item.code"
                                :label="item.name"
                                :value="item">
                        </el-option>
                    </el-select>
                </el-form-item>
                <el-form-item label="事件类型：">
                    <el-radio-group v-model="form.transferData" class="levelOfRisk">
                        <el-radio v-for="(item,index) in form.levelOfRisk" :label="item.value" :key="index">
                            <span class="levelOfRisk-type">{{ item.name }}</span>
                        </el-radio>
                    </el-radio-group>
                </el-form-item>
                <div class="rightButtonSearch">
                    <el-input v-model="form.keyword" size="mini" placeholder="在此输入关键字搜索"></el-input>
                    <el-button class="el-icon-search" @click="handleSearch"></el-button>
                </div>
            </el-form>
        </el-form>
        <el-scrollbar style="height:286.22px">
            <div class="environmental-risk-list" v-for="(item,index) in list" :key="index"
                 :class="activeNum===index?'hover':''">
                <!--                <i class="state"></i>-->
                <img class="state" :src="getImgSrc()" style="background: none"/>
                <div>
                    <h3 @click="handleLocation()">事件名称:XXX事件</h3>
                    <h5>
                        事件事件:2021年3月21日
                        <el-button class="rt btn00fff6" size="mini" style="margin-right: 0.04rem;">删除</el-button>
                    </h5>
                    <p>
                        事件状态：<span>审批阶段</span>
                    </p>
                    <p>事件类型：<span>{{ item.properties.pipecode }}</span>
                        <el-button class="rt btn00fff6" size="mini" style="margin-right: 0.04rem;"
                                   @click="btnAffiliatedFacilities()">事件管理
                        </el-button>
                    </p>
                </div>
            </div>
        </el-scrollbar>
    </div>
</template>

<script>
import { LayerEntEmer } from '../../../../../conf/layers/LayerEntEmer'
import { LayerEvent } from '../../../../../conf/layers/LayerEvent'
import { LayerResources } from '../../../../../conf/layers/LayerResources'

import ReportPopup from './ReportPopup'

import WfsHelper from '@components/helpers/WfsHelper'
import AjaxUtils from '@utils/AjaxUtils'

export default {
  name: 'EventQuery',
  data () {
    return {
      list: [],
      activeNum: -1,
      LayerEvent: {},
      LayerResources: {},
      items: [LayerEvent, LayerResources],
      subItems: LayerEntEmer.layers,
      form: {
        pipelineType: '',
        dataType: '',
        keyword: '',
        transferData: 1,
        levelOfRisk: [
          {
            name: '真实事件',
            value: 1
          },
          {
            name: '模拟演练',
            value: 2
          }
        ]
      },
      WfsHelper: null
    }
  },
  mounted () {
    this.wfsHelper = new WfsHelper()
  },
  methods: {
    getImgSrc () {
      const icon = this.form.dataType.icon
      return icon ? 'assets/images/map/' + icon : ''
    },
    handleDataType () {
      this.list = []
    },
    handlePipelineType (val) {
      this.list = []
      for (let i = 0; i < this.items.length; i++) {
        const item = this.items[i]
        if (val === item.name) {
          this.subItems = item.layers
          return
        }
      }
    },
    async handleSearch () {
      this.list = []
      this.wfsHelper.clearFilter()
      // todo 现在企业应急还没区分开类型，后面改
      // this.wfsHelper.setTypeName([this.form.dataType.typeName])
      this.wfsHelper.setTypeName(['sewer:emergency'])
      if (this.form.keyword) {
        this.wfsHelper.addLike('name', this.form.keyword)
      }
      const res = await AjaxUtils.GetDataAsynByUrl(this.wfsHelper.getUrl(), {})
      this.list = res.features
      console.log(res)
      if (res instanceof Object && Object.prototype.hasOwnProperty.call(res, 'features')) {
        this.list = res.features
      }
    },
    handleLocation (val, index) {
      this.activeNum = index
      // layer && layer.openPopup()
      window.layerFactory.flyByFeature(val, this.form.dataType.code)
    },
    btnAffiliatedFacilities () {
      console.log('item')
      window.$layer.open({
        content: {
          content: ReportPopup, // 组件
          parent: this, // 父组件
          data: { // 传递的参数
            // storagePlaceId: e.layer.options.totransferData.StoragePlaceId
          }
        }
        // title: 'title' // 标题
      })
    }
  }
}
</script>

<style lang="less" scoped>

</style>
